Class: ReleaseCeremony::TagInspector

Inherits:
Object
  • Object
show all
Defined in:
lib/release_ceremony/tag_inspector.rb

Overview

Reports where the release tag currently points, locally and on the remote, refusing to guess when the tag data looks unexpected.

Defined Under Namespace

Classes: TagState

Instance Method Summary collapse

Constructor Details

#initialize(version:, runner:, remote:) ⇒ TagInspector

Returns a new instance of TagInspector.



9
10
11
12
13
# File 'lib/release_ceremony/tag_inspector.rb', line 9

def initialize(version:, runner:, remote:)
  @version = version
  @runner = runner
  @remote = remote
end

Instance Method Details

#callObject



15
16
17
# File 'lib/release_ceremony/tag_inspector.rb', line 15

def call
  TagState.new(local_sha: local_tag_sha, remote_sha: remote_tag_sha)
end